Page 72 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 72

Home

    property; and have in general been as short in their lives
    as they have been violent in their deaths.®

    But, why doesn't democracy work? Why isn't it a
    good form of government? The answer lies i ina fatal

    coos ce

    someone else. To live, man must either work or steal.
    Experience shows that he will do whichever is safest and
    easiest. Thus, the majority will always follow

    easiest. Thus, the majority will always follow
    demagogues who promise to use the law to give them
    other men's property, property usually taken by taxes.
    Once the law is perverted into a system of legalized
    plunder to redistribute wealth, a right sense of justice is
    destroyed. Special interest groups are then formed to
    lobby government for their share of the wealth. Class
    hatred is generated, violence and anarchy then usher in
    the fall of the government and the establishment of a

    follow

    This process is explained very well in the 1928 U. S.
    Army Training Manual as it gives a definition of

    A government of the masses. Authority derived
    through mass meeting or any form of direct expression.
    Results in mobocracy. Attitude toward property is
    communistic — negating property rights. Attitude
    toward law is that the will of the majority shall regulate,
    whether it be based upon deliberation or governed by
    passion, prejudice, and impulse, without restraint or

    67

    The American Republic

    tendency of man to aspire to live off the labors of

    dictatorship.

    democracy: